SystemOrganization addCategory: #'Neo-JSON-VAST-Core'!

!Number methodsFor: '*Neo-JSON-VAST-Core' stamp: 'marianopeck 1/31/2018 11:29'!
closeTo: num
	"Tell whether the receiver and arguments are close from each."

	num isFloat ifTrue: [ ^ num closeTo: self asFloat ].
	^ [ self = num ] ifError: [ false ]! !

!Number methodsFor: '*Neo-JSON-VAST-Core' stamp: 'marianopeck 1/31/2018 11:29'!
closeTo: num precision: aPrecision
	"are these two numbers close?"

	num isFloat ifTrue: [ ^ num closeTo: self asFloat precision: aPrecision ].
	^ [ self = num ] ifError: [ false ]! !

!Symbol methodsFor: '*Neo-JSON-VAST-Core' stamp: 'marianopeck 1/31/2018 09:13'!
asMutator
	"Return a setter message from a getter message. For example,
	#name asMutator returns #name:
	return self if it is already a setter"
	(self size > 0 and: [self last == $:]) ifTrue:[ ^ self ].
	^ (self copyWith: $:) asSymbol! !

!NeoJSONWriter class methodsFor: '*Neo-JSON-VAST-Core' stamp: 'MarianoMartinezPeck 1/30/2018 10:08'!
new
	^super new initialize! !

!NeoJSONObjectMapping class methodsFor: '*Neo-JSON-VAST-Core' stamp: 'MarianoMartinezPeck 1/30/2018 10:06'!
new
	^super new initialize! !

!KeyedCollection classSide methodsFor: '*Neo-JSON-VAST-Core' stamp: 'marianopeck 1/31/2018 11:32'!
newFromPairs: anArray
	"Answer an instance of me associating (anArray at: i) to (anArray at: i+1)
	 for each odd i.  anArray must have an even number of entries."

	"Dictionary newFromPairs: {'Red' . Color red . 'Blue' . Color blue . 'Green' . Color green}."

	| newDictionary |
	newDictionary := self new: anArray size / 2.
	1 to: anArray size - 1 by: 2 do: [ :i | newDictionary at: (anArray at: i) put: (anArray at: i + 1) ].
	^ newDictionary! !

!KeyedCollection methodsFor: '*Neo-JSON-VAST-Core' stamp: 'MarianoMartinezPeck 1/30/2018 09:42'!
neoJsonOn: neoJSONWriter
	neoJSONWriter writeMap: self! !

!NeoJSONObject class methodsFor: '*Neo-JSON-VAST-Core' stamp: 'marianopeck 1/31/2018 11:23'!
newFrom: aDictOrCollection 
	"In Pharo, NeoJSONObject would inherit the implementation from Dictionary, which will work correctly for aDictOrCollection. In VAST, we do not have #newFrom, not all collections understand #associationsDo:  so we implement a custom solution that works for dictionaries and collections with a simply IF. To be improved later. "
	| newDictionary block |
	newDictionary := self new: aDictOrCollection size.
	block := [:x |
		(newDictionary includesKey: x key)
			ifTrue: [self error: 'Duplicate key: ', x key printString]
			ifFalse: [newDictionary add: x]].
	aDictOrCollection isDictionary 
		ifTrue: [ aDictOrCollection associationsDo:  block ] 
		ifFalse: [ aDictOrCollection do: block ].		
	^ newDictionary
! !

!Float methodsFor: '*Neo-JSON-VAST-Core' stamp: 'marianopeck 1/31/2018 11:29'!
closeTo: num
 	"Tell whether the receiver and arguments are close from each."
	
	^ self closeTo: num precision: 0.0001! !

!Float methodsFor: '*Neo-JSON-VAST-Core' stamp: 'marianopeck 1/31/2018 11:29'!
closeTo: num precision: aPrecision
 	"Tell whether the receiver and arguments are close from each other given a precision"
	
	num isNumber ifFalse: [ ^ [self = num] ifError: [false]].
	self = 0.0 ifTrue: [^ num abs < aPrecision].
	num = 0 ifTrue: [^self abs < aPrecision].
	^self = num asFloat
		or: [(self - num) abs / (self abs max: num abs) < aPrecision]! !

!NeoJSONStreamingWriter class methodsFor: '*Neo-JSON-VAST-Core' stamp: 'MarianoMartinezPeck 1/30/2018 10:08'!
new
	^super new initialize! !

!NeoJSONReader class methodsFor: '*Neo-JSON-VAST-Core' stamp: 'MarianoMartinezPeck 1/30/2018 10:07'!
new
	^super new initialize! !

!Collection methodsFor: '*Neo-JSON-VAST-Core' stamp: 'marianopeck 1/31/2018 09:14'!
removeAllSuchThat: aBlock 
	^self removeAll: (self select: aBlock)! !

!WriteStream methodsFor: '*Neo-JSON-VAST-Core' stamp: 'marianopeck 1/31/2018 09:37'!
<< anObject
	"A more readable, shorter alternative to #nextPutAll: that also
	accepts non-Collection arguments"

	anObject class == collection class
		ifTrue: [ self nextPutAll: anObject ]
		ifFalse: [ anObject putOn: self ]! !
